Use an AsyncWrite as a Sink<Item: AsRef<[u8]>.
This adapter produces a sink that will write each value passed to it into the underlying writer. Note that this function consumes the given writer, returning a wrapped version.
use tokio_into_sink::IntoSinkExt as _;
use futures::{stream, StreamExt as _};
use std::io;
let stream = stream::iter(["hello", "world"]).map(io::Result::Ok);
let write = tokio::fs::File::create("/dev/null").await.unwrap();
let sink = write.into_sink();
stream.forward(sink).await.unwrap();Ported from futures::io::AsyncWriteExt::into_sink.
Structs
- Into
Sink - See the module documentation.